@@ -1,7 +1,7 @@
 #' Load BdE catalogs
 #'
 #' @description
-#' Load the time-series catalogs provided by BdE.
+#' Load the time-series catalogs provided by the BdE.
 #'
 #' @export
 #'
@@ -9,7 +9,7 @@
 #'
 #' @encoding UTF-8
 #'
-#' @return A [`tibble`][tibble::tibble] object.
+#' @return A [tibble][tibble::tbl_df] object.
 #'
 #' @source
 #'
@@ -22,14 +22,14 @@
 #'
 #' ```
 #'
-#' @param catalog A single value indicating the catalogs to be updated
-#'   or `"ALL"` as a shorthand. See **Details**.
+#' @param catalog A single value indicating the catalogs to be updated or
+#'   `"ALL"` as a shorthand. See **Details**.
 #'
-#' @param parse_dates Logical. If `TRUE` the dates would be parsed using
+#' @param parse_dates Logical. If `TRUE`, the dates will be parsed using
 #'  [bde_parse_dates()].
 #'
-#' @param update_cache Logical. If `TRUE` the requested file would be updated on
-#'  the `cache_dir`.
+#' @param update_cache Logical. If `TRUE`, the requested file will be updated
+#'   in the `cache_dir`.
 #'
 #' @inheritParams bde_catalog_update
 #'
@@ -61,22 +61,29 @@
 #' \donttest{
 #' bde_catalog_load("TI", verbose = TRUE)
 #' }
-bde_catalog_load <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
-                             parse_dates = TRUE, cache_dir = NULL,
-                             update_cache = FALSE, verbose = FALSE) {
+bde_catalog_load <- function(
+  catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
+  parse_dates = TRUE,
+  cache_dir = NULL,
+  update_cache = FALSE,
+  verbose = FALSE
+) {
   catalog <- match.arg(catalog)
   # Validate
   valid_catalogs <- c("BE", "SI", "TC", "TI", "PB", "ALL")
   stopifnot(
-    catalog %in% valid_catalogs, length(catalog) == 1,
+    catalog %in% valid_catalogs,
+    length(catalog) == 1,
     any(is.null(cache_dir), is.character(cache_dir)),
-    is.logical(verbose), is.logical(parse_dates),
+    is.logical(verbose),
+    is.logical(parse_dates),
     is.logical(update_cache)
   )
 
-
   catalog_to_load <- catalog
-  if (catalog == "ALL") catalog_to_load <- setdiff(valid_catalogs, "ALL")
+  if (catalog == "ALL") {
+    catalog_to_load <- setdiff(valid_catalogs, "ALL")
+  }
 
   # Get cache dir
   cache_dir <- bde_hlp_cachedir(cache_dir = cache_dir, verbose = verbose)
@@ -90,10 +97,13 @@ bde_catalog_load <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
       if (verbose) message("tidyBdE> Cached version of ", x, " detected")
     } else {
       # If no catalog is found or requested, update
-      if (verbose) message("tidyBdE> Need to download catalog ", x)
+      if (verbose) {
+        message("tidyBdE> Need to download catalog ", x)
+      }
 
       result <- bde_catalog_update(
-        catalog = x, cache_dir = cache_dir,
+        catalog = x,
+        cache_dir = cache_dir,
         verbose = verbose
       )
 
@@ -104,7 +114,6 @@ bde_catalog_load <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
       }
     }
 
-
     # Catch error
     # nocov start
     r <- readLines(catalog_file)
@@ -114,10 +123,13 @@ bde_catalog_load <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
     }
     # nocov end
 
-    catalog_load <- read.csv2(catalog_file,
+    catalog_load <- read.csv2(
+      catalog_file,
       sep = ",",
-      stringsAsFactors = FALSE, na.strings = "",
-      header = FALSE, fileEncoding = "latin1"
+      stringsAsFactors = FALSE,
+      na.strings = "",
+      header = FALSE,
+      fileEncoding = "latin1"
     )
 
     # Convert names
@@ -162,23 +174,26 @@ bde_catalog_load <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
 
   # Unlist
   final_catalog <- dplyr::bind_rows(final_catalog)
-  final_catalog <- bde_hlp_guess(final_catalog,
+  final_catalog <- bde_hlp_guess(
+    final_catalog,
     preserve = names(final_catalog)[c(5, 15)]
   )
 
-
   # To tibble
   final_catalog <- tibble::as_tibble(final_catalog)
 
-
   # Parse dates dates
   if (parse_dates) {
     if (verbose) {
       message("tidyBdE> Parsing dates")
     }
-    date_fields <- names(final_catalog)[grep("Fecha", names(final_catalog))]
+    date_fields <- names(final_catalog)[grep(
+      "Fecha",
+      names(final_catalog),
+      fixed = TRUE
+    )]
 
-    for (i in seq_len(length(date_fields))) {
+    for (i in seq_along(date_fields)) {
       field <- date_fields[i]
       final_catalog[field] <- bde_parse_dates(final_catalog[[field]])
     }
@@ -245,8 +260,11 @@ bde_catalog_load <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
 #' \donttest{
 #' bde_catalog_update("TI", verbose = TRUE)
 #' }
-bde_catalog_update <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
-                               cache_dir = NULL, verbose = FALSE) {
+bde_catalog_update <- function(
+  catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
+  cache_dir = NULL,
+  verbose = FALSE
+) {
   catalog <- match.arg(catalog)
   # Validate
   valid_catalogs <- c("BE", "SI", "TC", "TI", "PB", "ALL")
@@ -292,13 +310,14 @@ bde_catalog_update <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
 
     # Download
     result <- bde_hlp_download(
-      url = full_url, local_file = local_file,
+      url = full_url,
+      local_file = local_file,
       verbose = verbose
     )
     result
   })
 
-  return(invisible(res))
+  invisible(res)
 }
 
 #' Search BdE catalogs
@@ -310,9 +329,9 @@ bde_catalog_update <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
 #'
 #' @family  catalog
 #'
-#' @return A [`tibble`][tibble::tibble] object with the results of the query.
+#' @return A [tibble][tibble::tbl_df] object with the results of the query.
 #'
-#' @param pattern [`regex`][base::regex]  pattern to search See **Details**
+#' @param pattern [`regex`][base::regex] pattern to search. See **Details**
 #'   and **Examples**.
 #'
 #' @inheritDotParams bde_catalog_load
@@ -320,13 +339,12 @@ bde_catalog_update <- function(catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
 #' @encoding UTF-8
 #'
 #' @details
-#' **Note that** BdE files are only provided in Spanish, for the time being.
-#' Therefore search terms should be provided in Spanish as well in order to get
-#' search results.
+#' **Note:** BdE files are currently provided only in Spanish. Therefore, search
+#' terms should be provided in Spanish to obtain search results.
 #'
-#' This function uses [base::grep()] function for finding matches on
-#' the catalogs. You can pass [regular expressions][base::regex] to broaden
-#' the search.
+#' This function uses [base::grep()] function for finding matches on the
+#' catalogs. You can pass [regular expressions][base::regex] to broaden the
+#' search.
 #'
 #' @seealso [bde_catalog_load()], [base::regex]
 #'
@@ -366,9 +384,10 @@ bde_catalog_search <- function(pattern, ...) {
   # Loop thorugh cols
   for (i in col_ind) {
     search_match_rows <- unique(
-      c(search_match_rows, grep(pattern, catalog_search[[i]],
-        ignore.case = TRUE, useBytes = TRUE
-      ))
+      c(
+        search_match_rows,
+        grep(pattern, catalog_search[[i]], ignore.case = TRUE, useBytes = TRUE)
+      )
     )
   }
 
