@@ -17,14 +17,14 @@
 #'
 #' @inheritDotParams bde_series_load -series_code
 #'
-#' @return A [`tibble`][tibble::tibble] with the required series.
+#' @return A [tibble][tibble::tbl_df] with the required series.
 #'
 #' @seealso [bde_series_load()], [bde_catalog_search()]
 #'
 #' @details
-#' This functions are convenient wrappers of [bde_series_load()] referencing
-#' specific series. Use `verbose = TRUE, extract_metadata = TRUE` options
-#' to see the specification and the source.
+#' These functions are convenient wrappers around [bde_series_load()] for
+#' specific series. Use `verbose = TRUE, extract_metadata = TRUE` to see the
+#' specification and the source.
 #'
 #' @examplesIf bde_check_access()
 #' \donttest{
@@ -54,7 +54,6 @@ bde_ind_unemployment_rate <-
     ]
     seq_num <- as.character(seq_num)
 
-
     econom_ind <- bde_series_load(seq_num, series_label = series_label, ...)
     econom_ind <- econom_ind[!is.na(econom_ind[[2]]), ]
 
@@ -65,8 +64,7 @@ bde_ind_unemployment_rate <-
 #'
 #' @export
 bde_ind_euribor_12m_monthly <-
-  function(series_label = "Euribor_12M_Monthly",
-           ...) {
+  function(series_label = "Euribor_12M_Monthly", ...) {
     db <- tidyBdE::bde_ind_db
     seq_num <- db[
       db$tidyBdE_fun == "bde_ind_euribor_12m_monthly",
@@ -179,7 +177,6 @@ bde_ind_population <- function(series_label = "Population_Spain", ...) {
   ]
   seq_num <- as.character(seq_num)
 
-
   econom_ind <- bde_series_load(seq_num, series_label = series_label, ...)
   econom_ind <- econom_ind[!is.na(econom_ind[[2]]), ]
 
