@@ -9,52 +9,49 @@
 #'
 #' @encoding UTF-8
 #'
-#' @param series_code a numeric (or coercible with [base::as.double()] value
-#'   or vector with time-series code(s), as defined in the field
+#' @param series_code A numeric value (or coercible with [base::as.double()])
+#'   or vector of time-series code(s), as defined in the field
 #'   `Número secuencial` of the corresponding series. See [bde_catalog_load()].
 #'
-#' @param series_label Optional. Character vector or value. Allows to specify a
-#'   custom label for the series extracted. It should have the same length than
-#'   `series_code`.
+#' @param series_label Optional. Character vector or value. Allows specifying a
+#'   custom label for the series extracted.
 #'
-#' @param out_format Defines if the format must be returned as a "long" dataset
-#'   or a "wide" dataset. Possible values are `"wide"` or `"long"`. See
-#'   **Value** for Details and Section **Examples**.
+#' @param out_format Whether the format should be returned as "long" or "wide".
+#'   Possible values are `"wide"` or `"long"`. See **Value** for details and
+#'   section **Examples**.
 #' @inheritParams bde_series_full_load
 #'
 #'
 #' @return
-#' A [`tibble`][tibble::tibble] with a field `Date` and :
-#' - With `out_format = "wide"` each series is presented in a separate
+#' A [tibble][tibble::tbl_df] with a field `Date`:
+#' - With `out_format = "wide"`, each series is presented in a separate
 #'   column with the name defined by `series_label`.
-#' - With `out_format = "long"` the `tibble` would have two more columns,
-#'   `serie_name` with the labels of each series and `serie_value` with the
-#'   value of the series.
+#' - With `out_format = "long"`, the tibble has two additional columns:
+#'   - `serie_name` with the label of each series.
+#'   - `serie_value` with the corresponding value.
 #'
 #' `"wide"` format is more suitable for exporting to a `.csv` file while
-#' `"long"` format is more suitable for producing plots with
+#' `"long"` format is more suitable for creating plots with
 #' [ggplot2::ggplot()]. See also [tidyr::pivot_longer()] and
 #' [tidyr::pivot_wider()].
 #'
 #' @description
 #'
 #' The series alias is a positional code showing the location (column and/or
-#' row) of the series in the table. However, although it is unique, it is not
-#' a good candidate to be used as the series ID, as it is subject to change.
-#'  If a series changes position in the table, its alias will also change.
+#' row) of the series in the table. However, although it is unique, it is not a
+#' good candidate to be used as the series ID, as it is subject to change. If a
+#' series changes position in the table, its alias will also change.
 #'
-#' To ensure series can still be identified, even after these changes, they
-#' are assigned a sequential number (`series_code` on this function) which
-#' will remain unchanged throughout the series' lifetime.
+#' To ensure series can still be identified, even after these changes, they are
+#' assigned a sequential number (referred to as `series_code` in this function).
 #'
-#' Note that a single series could be used on different tables, so it can have
-#' several aliases. If you need to search by alias it is recommended to use
+#' Note that a single series may appear in different tables, so it can have
+#' several aliases. If you need to search by alias, use
 #' [bde_series_full_load()].
 #'
 #' @note
-#' This function tries to coerce the columns to numbers. For some series a
-#' warning may be displayed if the parser fails. You can override the default
-#' behavior with `parse_numeric = FALSE`
+#' This function attempts to coerce the columns to numbers. For some series, a
+#' warning may be displayed if the parsing fails.
 #'
 #' @seealso [bde_catalog_load()],
 #' [bde_catalog_search()], [bde_indicators()]
@@ -99,11 +96,17 @@
 #'   scale_color_bde_d() +
 #'   theme_tidybde()
 #' }
-bde_series_load <- function(series_code, series_label = NULL,
-                            out_format = "wide", parse_dates = TRUE,
-                            parse_numeric = TRUE, cache_dir = NULL,
-                            update_cache = FALSE, verbose = FALSE,
-                            extract_metadata = FALSE) {
+bde_series_load <- function(
+  series_code,
+  series_label = NULL,
+  out_format = "wide",
+  parse_dates = TRUE,
+  parse_numeric = TRUE,
+  cache_dir = NULL,
+  update_cache = FALSE,
+  verbose = FALSE,
+  extract_metadata = FALSE
+) {
   if (missing(series_code)) {
     stop("`series_code` can't be NULL")
   }
@@ -115,7 +118,7 @@ bde_series_load <- function(series_code, series_label = NULL,
   if (is.null(series_label)) {
     series_label <- as.character(series_code)
   }
-  if (any(is.na(series_label))) {
+  if (anyNA(series_label)) {
     stop("`series_label` should not contain NA values")
   }
 
@@ -127,7 +130,8 @@ bde_series_load <- function(series_code, series_label = NULL,
 
   # Lookup on catalogs
   all_catalogs <- bde_catalog_load(
-    catalog = "ALL", parse_dates = parse_dates,
+    catalog = "ALL",
+    parse_dates = parse_dates,
     cache_dir = cache_dir,
     update_cache = update_cache,
     verbose = verbose
@@ -143,7 +147,9 @@ bde_series_load <- function(series_code, series_label = NULL,
   all_catalogs <- all_catalogs[!is.na(all_catalogs[[2]]), c(2, 3, 4)]
 
   df_list <- lapply(series_code, function(x) {
-    if (verbose) message("tidyBdE> Extracting series ", x, "\n\n")
+    if (verbose) {
+      message("tidyBdE> Extracting series ", x, "\n\n")
+    }
 
     # Select file
 
@@ -161,14 +167,19 @@ bde_series_load <- function(series_code, series_label = NULL,
 
     if (verbose) {
       message(
-        "tidyBdE> Downloading serie ", x, " from file ",
-        csv_file_name, " (alias ", alias_serie, ")."
+        "tidyBdE> Downloading serie ",
+        x,
+        " from file ",
+        csv_file_name,
+        " (alias ",
+        alias_serie,
+        ")."
       )
     }
 
-
     # Download and select series
-    serie_file <- bde_series_full_load(csv_file_name,
+    serie_file <- bde_series_full_load(
+      csv_file_name,
       parse_dates = parse_dates,
       parse_numeric = parse_numeric,
       cache_dir = cache_dir,
@@ -185,8 +196,12 @@ bde_series_load <- function(series_code, series_label = NULL,
     if (!(alias_serie %in% names(serie_file))) {
       if (verbose) {
         message(
-          "tidyBdE> ", "Serie with alias '", alias_serie,
-          "' not available on ", csv_file_name, ". "
+          "tidyBdE> ",
+          "Serie with alias '",
+          alias_serie,
+          "' not available on ",
+          csv_file_name,
+          ". "
         )
       }
 
@@ -215,10 +230,12 @@ bde_series_load <- function(series_code, series_label = NULL,
 
   # Check that all dfs have Date field
 
-  has_date <- vapply(df_list, function(x) {
-    "Date" %in% names(x)
-  },
-  FUN.VALUE = logical(1)
+  has_date <- vapply(
+    df_list,
+    function(x) {
+      "Date" %in% names(x)
+    },
+    FUN.VALUE = logical(1)
   )
 
   df_list <- df_list[has_date]
@@ -235,20 +252,19 @@ bde_series_load <- function(series_code, series_label = NULL,
   # Factors
 
   if (out_format == "wide" || isTRUE(extract_metadata)) {
-    end <- tidyr::pivot_wider(end,
-      id_cols = "Date", names_from = "serie_name",
+    end <- tidyr::pivot_wider(
+      end,
+      id_cols = "Date",
+      names_from = "serie_name",
       values_from = "serie_value"
     )
   }
 
   end <- tibble::as_tibble(end)
-  return(end)
+  end
 }
 
 
-
-
-
 #' Load BdE full time-series files
 #'
 #' Load a full time-series file provided by BdE.
@@ -263,12 +279,10 @@ bde_series_load <- function(series_code, series_label = NULL,
 #' For that reason, the function [bde_series_load()] is more suitable for
 #' extracting specific time-series.
 #'
-#'
 #' @export
 #'
 #' @family series
 #'
-#'
 #' @encoding UTF-8
 #'
 #' @param series_csv csv file of a series, as defined in the field
@@ -283,8 +297,9 @@ bde_series_load <- function(series_code, series_label = NULL,
 #' @param extract_metadata Logical `TRUE/FALSE`. On `TRUE` the output is the
 #'   metadata of the requested series.
 #'
-#' @return A [tibble][tibble::tibble] with a field `Date` and the alias of the
-#' fields series as described on the catalogs. See [bde_catalog_load()].
+#' @return
+#' A [tibble][tibble::tbl_df] with a field `Date` and the alias of the fields
+#' series as described on the catalogs. See [bde_catalog_load()].
 #'
 #' @note
 #' This function tries to coerce the columns to numbers. For some series a
@@ -299,10 +314,15 @@ bde_series_load <- function(series_code, series_label = NULL,
 #' # Data
 #' bde_series_full_load("TI_1_1.csv")
 #' }
-bde_series_full_load <- function(series_csv, parse_dates = TRUE,
-                                 parse_numeric = TRUE, cache_dir = NULL,
-                                 update_cache = FALSE, verbose = FALSE,
-                                 extract_metadata = FALSE) {
+bde_series_full_load <- function(
+  series_csv,
+  parse_dates = TRUE,
+  parse_numeric = TRUE,
+  cache_dir = NULL,
+  update_cache = FALSE,
+  verbose = FALSE,
+  extract_metadata = FALSE
+) {
   stopifnot(
     is.null(cache_dir) || is.character(cache_dir),
     is.logical(verbose),
@@ -318,20 +338,21 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
 
   # Get cache dir
   cache_dir <- bde_hlp_cachedir(
-    cache_dir = cache_dir, verbose = verbose,
+    cache_dir = cache_dir,
+    verbose = verbose,
     suffix = pp
   )
 
   # Create if not exist
-  if (!dir.exists(cache_dir)) dir.create(cache_dir, recursive = TRUE)
-
+  if (!dir.exists(cache_dir)) {
+    dir.create(cache_dir, recursive = TRUE)
+  }
 
   base_url <- paste0(
     "https://www.bde.es/webbe/es/estadisticas/",
     "compartido/datos/csv/"
   )
 
-
   serie_file <- tolower(series_csv)
 
   full_url <- paste0(base_url, serie_file)
@@ -345,7 +366,8 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
     }
 
     result <- bde_hlp_download(
-      url = full_url, local_file = local_file,
+      url = full_url,
+      local_file = local_file,
       verbose = verbose
     )
 
@@ -363,7 +385,6 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
     }
   }
 
-
   # Catch error
   # nocov start
   r <- readLines(local_file)
@@ -373,11 +394,13 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
   }
   # nocov end
 
-
   # Serie load
-  serie_load <- read.csv2(local_file,
-    sep = ",", stringsAsFactors = FALSE,
-    na.strings = "", header = FALSE,
+  serie_load <- read.csv2(
+    local_file,
+    sep = ",",
+    stringsAsFactors = FALSE,
+    na.strings = "",
+    header = FALSE,
     fileEncoding = "latin1"
   )
 
@@ -389,7 +412,6 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
 
   names(serie_load) <- newnames
 
-
   # Metadata
   # Always lines 1 to 6
   meta_serie <- serie_load[seq_len(6), ]
@@ -418,9 +440,13 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
     if (verbose) {
       message("tidyBdE> Parsing dates")
     }
-    date_fields <- names(data_serie)[grep("Date", names(data_serie))]
+    date_fields <- names(data_serie)[grep(
+      "Date",
+      names(data_serie),
+      fixed = TRUE
+    )]
 
-    for (i in seq_len(length(date_fields))) {
+    for (i in seq_along(date_fields)) {
       field <- date_fields[i]
 
       data_serie[field] <- bde_parse_dates(data_serie[[field]])
@@ -428,9 +454,11 @@ bde_series_full_load <- function(series_csv, parse_dates = TRUE,
   }
 
   if (parse_numeric) {
-    if (verbose) message("tidyBdE> Parsing fields to double")
+    if (verbose) {
+      message("tidyBdE> Parsing fields to double")
+    }
     # Fields to double
     data_serie <- bde_hlp_todouble(data_serie, preserve = "Date")
   }
-  return(data_serie)
+  data_serie
 }
