@@ -13,8 +13,8 @@
 #' @param dates_to_parse Dates to parse
 #'
 #' @description
-#' This function is tailored for the date formatting used on this package, so
-#' it may fail if it is used for another datasets. See **Examples** for
+#' This function is tailored for the date formatting used in this package,
+#' so it may fail if used with other datasets. See **Examples** for
 #' checking which formats would be considered.
 #'
 #' ## Date Formats
@@ -69,22 +69,32 @@
 #'
 #' tibble::tibble(raw = wont_parse, parsed = parsed_fail)
 bde_parse_dates <- function(dates_to_parse) {
-  dateformat <- gsub(" ", "", toupper(dates_to_parse))
-  dateformat <- gsub("-", "", dateformat)
-  dateformat <- gsub("/", "", dateformat)
+  dateformat <- gsub(" ", "", toupper(dates_to_parse), fixed = TRUE)
+  dateformat <- gsub("-", "", dateformat, fixed = TRUE)
+  dateformat <- gsub("/", "", dateformat, fixed = TRUE)
 
   months_esp <- c(
-    "ENE", "FEB", "MAR", "ABR", "MAY", "JUN", "JUL", "AGO",
-    "SEP", "OCT", "NOV", "DIC"
+    "ENE",
+    "FEB",
+    "MAR",
+    "ABR",
+    "MAY",
+    "JUN",
+    "JUL",
+    "AGO",
+    "SEP",
+    "OCT",
+    "NOV",
+    "DIC"
   )
 
   # Format months
-  for (i in seq_len(length(months_esp))) {
+  for (i in seq_along(months_esp)) {
     dateformat <- gsub(months_esp[i], sprintf("%02d", i), dateformat)
   }
 
   # Final format: dd-mm-yyyy
-  for (j in seq_len(length(dateformat))) {
+  for (j in seq_along(dateformat)) {
     s2 <- dateformat[j]
 
     if (is.na(s2) || nchar(s2) < 4) {
@@ -167,14 +177,12 @@ bde_hlp_cachedir <- function(cache_dir = NULL, verbose = FALSE, suffix = NULL) {
 #'
 #' @noRd
 bde_hlp_download <- function(url, local_file, verbose) {
-  if (verbose) message("tidyBdE> Downloading file from ", url, "\n\n")
+  if (verbose) {
+    message("tidyBdE> Downloading file from ", url, "\n\n")
+  }
 
   err_dwnload <- tryCatch(
-    download.file(url,
-      local_file,
-      quiet = isFALSE(verbose),
-      mode = "wb"
-    ),
+    download.file(url, local_file, quiet = isFALSE(verbose), mode = "wb"),
     # nocov start
     warning = function(e) {
       TRUE
@@ -186,17 +194,18 @@ bde_hlp_download <- function(url, local_file, verbose) {
 
   # nocov start
   if (isTRUE(err_dwnload)) {
-    if (verbose) message("tidyBdE> Trying again")
+    if (verbose) {
+      message("tidyBdE> Trying again")
+    }
 
     err_dwnload <- tryCatch(
-      download.file(url, local_file,
-        quiet = isFALSE(verbose),
-        mode = "wb"
-      ),
+      download.file(url, local_file, quiet = isFALSE(verbose), mode = "wb"),
       # nocov start
       warning = function(e) {
         message(
-          "tidyBdE> URL \n ", url, "\nnot reachable.\n\n",
+          "tidyBdE> URL \n ",
+          url,
+          "\nnot reachable.\n\n",
           "If you think this is a bug consider opening an issue"
         )
         TRUE
@@ -222,7 +231,8 @@ bde_hlp_download <- function(url, local_file, verbose) {
 bde_hlp_guess <- function(tbl, preserve = "") {
   for (i in names(tbl)) {
     if (class(tbl[[i]])[1] == "character" && !(i %in% preserve)) {
-      tbl[i] <- readr::parse_guess(tbl[[i]],
+      tbl[i] <- readr::parse_guess(
+        tbl[[i]],
         locale = readr::locale(
           grouping_mark = "",
           decimal_mark = "."
@@ -231,7 +241,7 @@ bde_hlp_guess <- function(tbl, preserve = "") {
       )
     }
   }
-  return(tbl)
+  tbl
 }
 
 
@@ -246,7 +256,7 @@ bde_hlp_tochar <- function(tbl, preserve = "") {
       tbl[i] <- as.character(tbl[[i]])
     }
   }
-  return(tbl)
+  tbl
 }
 
 
@@ -259,7 +269,8 @@ bde_hlp_todouble <- function(tbl, preserve = "") {
   for (i in names(tbl)) {
     if (class(tbl[[i]])[1] == "character" && !(i %in% preserve)) {
       tbl[i] <-
-        readr::parse_double(tbl[[i]],
+        readr::parse_double(
+          tbl[[i]],
           locale = readr::locale(
             grouping_mark = "",
             decimal_mark = "."
@@ -268,7 +279,7 @@ bde_hlp_todouble <- function(tbl, preserve = "") {
         )
     }
   }
-  return(tbl)
+  tbl
 }
 
 
@@ -283,6 +294,6 @@ bde_hlp_return_null <- function(msg = "Offline. Returning an empty tibble") {
   # nocov start
   message(paste0("tidyBdE> ", msg))
   tbl <- tibble::tibble(x = NULL)
-  return(tbl)
+  tbl
   # nocov end
 }
