@@ -1,7 +1,5 @@
 test_that("Test error", {
-  expect_snapshot(bde_tidy_palettes(palette = "none"),
-    error = TRUE
-  )
+  expect_snapshot(bde_tidy_palettes(palette = "none"), error = TRUE)
 })
 
 
@@ -25,7 +23,6 @@ test_that("Switch pal", {
 })
 
 
-
 test_that("test n", {
   ok <- bde_tidy_palettes(n = 6)
   ok3 <- bde_tidy_palettes(n = 3)
